[otrs-cvs] ITSMConfigurationManagement/Kernel/System/ITSMConfigItem History.pm, 1.10, 1.10.4.1

"CVS commits notifications of OTRS.org" <[email protected]>
Newsgroups gmane.comp.otrs.cvs
Message-ID <[email protected]>
Comments:
Update of /home/cvs/ITSMConfigurationManagement/Kernel/System/ITSMConfigItem
In directory lancelot:/tmp/cvs-serv29825/Kernel/System/ITSMConfigItem

Modified Files:
      Tag: rel-3_1
	History.pm 
Log Message:
Small Code Improvement.

Author: ub

Index: History.pm
===================================================================
RCS file: /home/cvs/ITSMConfigurationManagement/Kernel/System/ITSMConfigItem/History.pm,v
retrieving revision 1.10
retrieving revision 1.10.4.1
diff -2 -u -d -r1.10 -r1.10.4.1
--- History.pm	27 Sep 2011 07:00:59 -0000	1.10
+++ History.pm	20 Dec 2012 10:17:54 -0000	1.10.4.1
@@ -1,5 +1,5 @@
 # --
 # Kernel/System/ITSMConfigItem/History.pm - module for ITSMConfigItem.pm with history functions
-# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
 # $Id$
@@ -270,9 +270,12 @@
     }
 
     # check if given config item id points to an existing config item id
     if ( $Param{ConfigItemID} ) {
-        my $Id = $Self->ConfigItemLookup( ConfigItemID => $Param{ConfigItemID} );
 
-        if ( !$Id ) {
+        my $Number = $Self->ConfigItemLookup(
+            ConfigItemID => $Param{ConfigItemID},
+        );
+
+        if ( !$Number ) {
             $Self->{LogObject}->Log(
                 Priority => 'error',
---------------------------------------------------------------------
@@ -270,9 +270,12 @@
     }
 
-    # check if given config item id points to an existing config item id
+    # check if given config item id points to an existing config item number
     if ( $Param{ConfigItemID} ) {
OTRS mailing list: cvs-log - Webpage: http://otrs.org/
Archive: http://lists.otrs.org/pipermail/cvs-log
To unsubscribe: http://lists.otrs.org/cgi-bin/listinfo/cvs-log
lmpx.com only provides a reader for public news (NNTP) servers. It is not affiliated with the servers or forums shown here and is not responsible for the content of articles, which is written by their respective authors.